@@ -5,7 +5,6 @@ use warnings;
 use vars    qw[@ISA $STATUS $VERSION];
 @ISA =      qw[CPANPLUS::Dist];
 
-use CPANPLUS::inc;
 use CPANPLUS::Internals::Constants;
 
 ### these constants were exported by CPANPLUS::Internals::Constants
@@ -31,7 +30,7 @@ use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 
 local $Params::Check::VERBOSE = 1;
 
-$VERSION = '0.13_02';
+$VERSION = '0.35_01';
 
 =pod
 
@@ -264,10 +263,10 @@ sub prepare {
     ### to reset the @INC
     #local $ENV{PERL5OPT} = CPANPLUS::inc->original_perl5opt;
     #local $ENV{PERL5LIB} = CPANPLUS::inc->original_perl5lib;
-    local @INC           = CPANPLUS::inc->original_inc;
+    #local @INC           = CPANPLUS::inc->original_inc;
 
     ### this will generate warnings under anything lower than M::B 0.2606
-    my %buildflags = $dist->_buildflags_as_hash( $buildflags );
+    my @buildflags = $dist->_buildflags_as_list( $buildflags );
     $dist->status->_buildflags( $buildflags );
 
     my $fail;
@@ -309,10 +308,11 @@ sub prepare {
         # done at a much higher level).
         my $prep_output;
 
-        my $env = 'ENV_CPANPLUS_IS_EXECUTING';
+        my $env = ENV_CPANPLUS_IS_EXECUTING;
         local $ENV{$env} = BUILD_PL->( $dir );
+        my $run_perl    = $conf->get_program('perlwrapper');
 
-        unless ( scalar run(    command => [$perl, BUILD_PL->($dir), $buildflags],
+        unless ( scalar run(    command => [$perl, $run_perl, BUILD_PL->($dir), @buildflags],
                                 buffer  => \$prep_output,
                                 verbose => $verbose ) 
         ) {
@@ -379,9 +379,13 @@ sub _find_prereqs {
     my $content;
 
     if ( version->new( $Module::Build::VERSION ) >= $safe_ver and ! ON_WIN32 ) {
+        my @buildflags = $dist->_buildflags_as_list( $buildflags );
+
         # Use the new Build action 'prereq_data'
-        
-        unless ( scalar run(    command => [$perl, BUILD->($dir), 'prereq_data', $buildflags],
+        my $run_perl    = $conf->get_program('perlwrapper');
+        my $flag    = ON_VMS ? '"prereq_data"' : 'prereq_data';
+
+        unless ( scalar run(    command => [$perl, $run_perl, BUILD->($dir), $flag, @buildflags],
                                 buffer  => \$content,
                                 verbose => 0 ) 
         ) {
@@ -499,7 +503,12 @@ sub create {
         $args = check( $tmpl, \%hash ) or return;
     }
 
-    return 1 if $dist->status->created && !$force;
+    # restore the state as we have created this already.
+    if ( $dist->status->created && !$force ) {
+        ### add this directory to your lib ###
+        $self->add_to_includepath();
+        return 1;
+    }
 
     $dist->status->_create_args( $args );
 
@@ -528,7 +537,7 @@ sub create {
     ### to reset the @INC
     #local $ENV{PERL5OPT} = CPANPLUS::inc->original_perl5opt;
     #local $ENV{PERL5LIB} = CPANPLUS::inc->original_perl5lib;
-    local @INC           = CPANPLUS::inc->original_inc;
+    #local @INC           = CPANPLUS::inc->original_inc;
 
     ### but do it *before* the new_from_context, as M::B seems
     ### to be actually running the file...
@@ -540,12 +549,14 @@ sub create {
                 if $self->best_path_to_module_build;
 
     ### this will generate warnings under anything lower than M::B 0.2606
-    my %buildflags = $dist->_buildflags_as_hash( $buildflags );
+    my @buildflags = $dist->_buildflags_as_list( $buildflags );
     $dist->status->_buildflags( $buildflags );
 
     my $fail; my $prereq_fail; my $test_fail;
     RUN: {
 
+        my $run_perl    = $conf->get_program('perlwrapper');
+
         ### this will set the directory back to the start
         ### dir, so we must chdir /again/
         my $ok = $dist->_resolve_prereqs(
@@ -573,7 +584,7 @@ sub create {
 
         my $captured;
 
-        unless ( scalar run(    command => [$perl, BUILD->($dir), $buildflags],
+        unless ( scalar run(    command => [$perl, $run_perl, BUILD->($dir), @buildflags],
                                 buffer  => \$captured,
                                 verbose => $verbose ) 
         ) {
@@ -595,7 +606,7 @@ sub create {
         unless( $skiptest ) {
             my $test_output;
             my $flag    = ON_VMS ? '"test"' : 'test';
-            my $cmd     = [$perl, BUILD->($dir), $flag, $buildflags];
+            my $cmd     = [$perl, $run_perl, BUILD->($dir), $flag, @buildflags];
             unless ( scalar run(    command => $cmd,
                                     buffer  => \$test_output,
                                     verbose => $verbose ) 
@@ -704,7 +715,9 @@ sub install {
     }
 
     my $fail;
-    my $buildflags = $dist->status->_buildflags;
+    my @buildflags = $dist->_buildflags_as_list( $dist->status->_buildflags );
+    my $run_perl    = $conf->get_program('perlwrapper');
+
     ### hmm, how is this going to deal with sudo?
     ### for now, check effective uid, if it's not root,
     ### shell out, otherwise use the method
@@ -715,7 +728,7 @@ sub install {
         ### M::B at the top of the build.pl
         ### On VMS, flags need to be quoted
         my $flag    = ON_VMS ? '"install"' : 'install';
-        my $cmd     = [$perl, BUILD->($dir), $flag, $buildflags];
+        my $cmd     = [$perl, $run_perl, BUILD->($dir), $flag, @buildflags];
         my $sudo    = $conf->get_program('sudo');
         unshift @$cmd, $sudo if $sudo;
 
@@ -729,11 +742,9 @@ sub install {
             $fail++;
         }
     } else {
-        my %buildflags = $dist->_buildflags_as_hash($buildflags);
-
         my $install_output;
         my $flag    = ON_VMS ? '"install"' : 'install';
-        my $cmd     = [$perl, BUILD->($dir), $flag, $buildflags];
+        my $cmd     = [$perl, $run_perl, BUILD->($dir), $flag, @buildflags];
         unless( scalar run( command => $cmd,
                             buffer  => \$install_output,
                             verbose => $verbose )
@@ -754,15 +765,13 @@ sub install {
     return $dist->status->installed( $fail ? 0 : 1 );
 }
 
-### returns the string 'foo=bar zot=quux' as (foo => bar, zot => quux)
-sub _buildflags_as_hash {
+### returns the string 'foo=bar --zot quux'
+###        as the list 'foo=bar', '--zot', 'qux'
+sub _buildflags_as_list {
     my $self    = shift;
     my $flags   = shift or return;
 
-    my @argv    = Module::Build->split_like_shell($flags);
-    my ($argv)  = Module::Build->read_args(@argv);
-
-    return %$argv;
+    return Module::Build->split_like_shell($flags);
 }
 
 =head1 AUTHOR
@@ -770,7 +779,7 @@ sub _buildflags_as_hash {
 Originally by Jos Boumans E<lt>kane@cpan.orgE<gt>.  Brought to working
 condition by Ken Williams E<lt>kwilliams@cpan.orgE<gt>.
 
-Other hackery and currently maintained by Chris 'BinGOs' Williams ( no relation ). E<lt>bingos@cpan.orgE<gt>.
+Other hackery and currently maintained by Chris C<BinGOs> Williams ( no relation ). E<lt>bingos@cpan.orgE<gt>.
 
 =head1 LICENSE
 
